package at.ac.uibk.gitsearch.security;

import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;

/**
 * Constants for Spring Security authorities.
 */
public final class AuthoritiesConstants {

    public static final String ADMIN = "ROLE_ADMIN";

    public static final String USER = "ROLE_USER";

    public static final String ANONYMOUS = "ROLE_ANONYMOUS";

    public static final String REVIEW_MANAGER = "ROLE_REVIEW_MANAGER";

    /** just a convenience enum to access authorities in all their variants */
    public enum AuthoritiesConstantEnum {
        ADMIN(AuthoritiesConstants.ADMIN),
        USER(AuthoritiesConstants.USER),
        ANONYMOUS(AuthoritiesConstants.ANONYMOUS);

        private String name;
        private GrantedAuthority grantedAuthority;

        AuthoritiesConstantEnum(String name) {
            this.name = name;
            grantedAuthority = new SimpleGrantedAuthority(name);
        }

        /**
         * @return the name
         */
        public String getName() {
            return name;
        }

        /**
         * @return the grantedAuthority
         */
        public GrantedAuthority getGrantedAuthority() {
            return grantedAuthority;
        }
    }

    public static final GrantedAuthority ADMIN_AUTHORITY = new SimpleGrantedAuthority(ADMIN);

    private AuthoritiesConstants() {}
}
