import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';

import { IReviewRating } from '../review-rating.model';
import { ReviewRatingService } from '../service/review-rating.service';
import { ReviewRatingDeleteDialogComponent } from '../delete/review-rating-delete-dialog.component';

@Component({
  selector: 'jhi-review-rating',
  templateUrl: './review-rating.component.html',
})
export class ReviewRatingComponent implements OnInit {
  reviewRatings?: IReviewRating[];
  isLoading = false;

  constructor(protected reviewRatingService: ReviewRatingService, protected modalService: NgbModal) {}

  loadAll(): void {
    this.isLoading = true;

    this.reviewRatingService.query().subscribe({
      next: (res: HttpResponse<IReviewRating[]>) => {
        this.isLoading = false;
        this.reviewRatings = res.body ?? [];
      },
      error: () => {
        this.isLoading = false;
      },
    });
  }

  ngOnInit(): void {
    this.loadAll();
  }

  trackId(index: number, item: IReviewRating): number {
    return item.id!;
  }

  delete(reviewRating: IReviewRating): void {
    const modalRef = this.modalService.open(ReviewRatingDeleteDialogComponent, { size: 'lg', backdrop: 'static' });
    modalRef.componentInstance.reviewRating = reviewRating;
    // unsubscribe not needed because closed completes on modal close
    modalRef.closed.subscribe(reason => {
      if (reason === 'deleted') {
        this.loadAll();
      }
    });
  }
}
