import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { FormBuilder, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { Observable } from 'rxjs';
import { finalize, map } from 'rxjs/operators';

import { IUserWatchList, UserWatchList } from '../user-watch-list.model';
import { UserWatchListService } from '../service/user-watch-list.service';
import { IUser } from 'app/entities/user/user.model';
import { UserService } from 'app/entities/user/user.service';
import { CheckFrequency } from 'app/entities/enumerations/check-frequency.model';

@Component({
  selector: 'jhi-user-watch-list-update',
  templateUrl: './user-watch-list-update.component.html',
})
export class UserWatchListUpdateComponent implements OnInit {
  isSaving = false;
  checkFrequencyValues = Object.keys(CheckFrequency);

  usersSharedCollection: IUser[] = [];

  editForm = this.fb.group({
    id: [],
    name: [null, [Validators.required, Validators.maxLength(255)]],
    checkFrequency: [null, [Validators.required]],
    user: [],
  });

  constructor(
    protected userWatchListService: UserWatchListService,
    protected userService: UserService,
    protected activatedRoute: ActivatedRoute,
    protected fb: FormBuilder
  ) {}

  ngOnInit(): void {
    this.activatedRoute.data.subscribe(({ userWatchList }) => {
      this.updateForm(userWatchList);

      this.loadRelationshipsOptions();
    });
  }

  previousState(): void {
    window.history.back();
  }

  save(): void {
    this.isSaving = true;
    const userWatchList = this.createFromForm();
    if (userWatchList.id !== undefined) {
      this.subscribeToSaveResponse(this.userWatchListService.update(userWatchList));
    } else {
      this.subscribeToSaveResponse(this.userWatchListService.create(userWatchList));
    }
  }

  trackUserById(index: number, item: IUser): number {
    return item.id!;
  }

  protected subscribeToSaveResponse(result: Observable<HttpResponse<IUserWatchList>>): void {
    result.pipe(finalize(() => this.onSaveFinalize())).subscribe({
      next: () => this.onSaveSuccess(),
      error: () => this.onSaveError(),
    });
  }

  protected onSaveSuccess(): void {
    this.previousState();
  }

  protected onSaveError(): void {
    // Api for inheritance.
  }

  protected onSaveFinalize(): void {
    this.isSaving = false;
  }

  protected updateForm(userWatchList: IUserWatchList): void {
    this.editForm.patchValue({
      id: userWatchList.id,
      name: userWatchList.name,
      checkFrequency: userWatchList.checkFrequency,
      user: userWatchList.user,
    });

    this.usersSharedCollection = this.userService.addUserToCollectionIfMissing(this.usersSharedCollection, userWatchList.user);
  }

  protected loadRelationshipsOptions(): void {
    this.userService
      .query()
      .pipe(map((res: HttpResponse<IUser[]>) => res.body ?? []))
      .pipe(map((users: IUser[]) => this.userService.addUserToCollectionIfMissing(users, this.editForm.get('user')!.value)))
      .subscribe((users: IUser[]) => (this.usersSharedCollection = users));
  }

  protected createFromForm(): IUserWatchList {
    return {
      ...new UserWatchList(),
      id: this.editForm.get(['id'])!.value,
      name: this.editForm.get(['name'])!.value,
      checkFrequency: this.editForm.get(['checkFrequency'])!.value,
      user: this.editForm.get(['user'])!.value,
    };
  }
}
